import { marshall } from '@aws-sdk/util-dynamodb';
import { mapKey } from './mapKey';
export const mapUpdateItemCommand = (config, item, createIfNotExists = false) => {
    const partitionKeyName = String(config.partitionKeyName);
    const partitionKey = item[config.partitionKeyName];
    const sortKeyName = String(config.sortKeyName);
    const sortKey = config.sortKeyName ? item[config.sortKeyName] : undefined;
    return {
        TableName: config.tableName,
        Key: mapKey(config, partitionKey, sortKey),
        ConditionExpression: createIfNotExists ? undefined : `#${partitionKeyName} = :${partitionKeyName} and #${sortKeyName} = :${sortKeyName}`,
        ExpressionAttributeValues: marshall(mapAttributes(config, item, createIfNotExists)
            .reduce((attributeValues, [key, value]) => ({
            ...attributeValues,
            [`:${key}`]: value,
        }), {})),
        ExpressionAttributeNames: mapAttributes(config, item, createIfNotExists)
            .reduce((attributeNames, [key]) => ({
            ...attributeNames,
            [`#${key}`]: key,
        }), {}),
        UpdateExpression: `SET ${Object.keys(item)
            .filter((key) => key !== config.partitionKeyName && key !== config.sortKeyName)
            .map((key) => `#${key}=:${key}`).join(',')}`,
        ReturnValues: 'ALL_NEW',
    };
};
const mapAttributes = (config, item, createIfNotExists = false) => {
    return Object.entries(item)
        .filter(([key]) => !createIfNotExists || (createIfNotExists && key !== config.partitionKeyName && key !== config.sortKeyName));
};
//# sourceMappingURL=mapUpdateItemCommand.js.map